@@ -37,6 +37,7 @@ from braintree.ideal_payment import IdealPayment
 from braintree.merchant import Merchant
 from braintree.merchant_account import MerchantAccount
 from braintree.merchant_account_gateway import MerchantAccountGateway
+from braintree.oauth_access_revocation import OAuthAccessRevocation
 from braintree.partner_merchant import PartnerMerchant
 from braintree.payment_instrument_type import PaymentInstrumentType
 from braintree.payment_method import PaymentMethod
@@ -46,6 +47,7 @@ from braintree.plan import Plan
 from braintree.plan_gateway import PlanGateway
 from braintree.resource_collection import ResourceCollection
 from braintree.risk_data import RiskData
+from braintree.samsung_pay_card import SamsungPayCard
 from braintree.search import Search
 from braintree.settlement_batch_summary import SettlementBatchSummary
 from braintree.signature_service import SignatureService
@@ -61,6 +63,7 @@ from braintree.transaction import Transaction
 from braintree.transaction_amounts import TransactionAmounts
 from braintree.transaction_details import TransactionDetails
 from braintree.transaction_gateway import TransactionGateway
+from braintree.transaction_line_item import TransactionLineItem
 from braintree.transaction_search import TransactionSearch
 from braintree.transparent_redirect import TransparentRedirect
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
